@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -24,41 +25,39 @@
 namespace polymake { namespace fan {
 
 template <typename Scalar, typename TVector>
-perl::Object mixed_subdivision(int m,
-                               const perl::Object cayley_embedding,
-                               const Array<Set<int> >& vertices_in_cells,
-                               const GenericVector<TVector>& t)
+BigObject mixed_subdivision(Int m,
+                            const BigObject cayley_embedding,
+                            const Array<Set<Int>>& vertices_in_cells,
+                            const GenericVector<TVector>& t)
 {
    // input sanity checks
    if (!m)
       throw std::runtime_error("mixed_subdivision: empty array given.");
 
    const Matrix<Scalar> V = cayley_embedding.give("VERTICES|POINTS");
-   const int d = V.cols() - m - 1; // common dimension of the input polytopes
+   const Int d = V.cols()-m-1; // common dimension of the input polytopes
 
    const Matrix<Scalar> slice_eqs = (-t) / accumulate(t.top(), operations::add())
                                   | zero_matrix<Scalar>(m,d)
                                   | unit_matrix<Scalar>(m);
 
-   hash_map<Vector<Scalar>, int> index_of_point;
-   int n_points(0);
+   hash_map<Vector<Scalar>, Int> index_of_point;
+   Int n_points = 0;
 
-   std::vector<Set<int>> vif_vector;
+   BigObjectType poly_type("Polytope", mlist<Scalar>());
+   std::vector<Set<Int>> vif_vector;
    for (auto vicit = entire(vertices_in_cells); !vicit.at_end(); ++vicit) {
 
-      perl::Object cayley_cell(perl::ObjectType::construct<Scalar>("Polytope"));
-      cayley_cell.take("POINTS") << V.minor(*vicit, All);
+      BigObject cayley_cell(poly_type, "POINTS", V.minor(*vicit, All));
       const Matrix<Scalar> F = cayley_cell.give("FACETS");
 
-      perl::Object cayley_slice(perl::ObjectType::construct<Scalar>("Polytope"));
-      cayley_slice.take("INEQUALITIES") << F;
-      cayley_slice.take("EQUATIONS") << slice_eqs;
+      BigObject cayley_slice(poly_type, "INEQUALITIES", F, "EQUATIONS", slice_eqs);
       const Matrix<Scalar> P = cayley_slice.give("VERTICES");
       if (!P.rows())
          throw std::runtime_error("mixed_subdivision: unexpectedly empty slice polytope");
 
-      Set<int> vif;
-      for (typename Entire<Rows<Matrix<Scalar> > >::const_iterator rit = entire(rows(P)); !rit.at_end(); ++rit) {
+      Set<Int> vif;
+      for (auto rit = entire(rows(P)); !rit.at_end(); ++rit) {
          const Vector<Scalar> pt(*rit);
          if (!index_of_point.exists(pt))
             index_of_point[pt] = n_points++;
@@ -68,20 +67,19 @@ perl::Object mixed_subdivision(int m,
    }
 
    Matrix<Scalar> V_out(index_of_point.size(), d+1);
-   for (typename Entire<hash_map<Vector<Scalar>,int> >::const_iterator hit = entire(index_of_point); !hit.at_end(); ++hit)
-      V_out[hit->second] = hit->first.slice(0, d+1);
+   for (auto hit = entire(index_of_point); !hit.at_end(); ++hit)
+      V_out[hit->second] = hit->first.slice(sequence(0, d+1));
 
-   perl::Object p_out(perl::ObjectType::construct<Scalar>("PolyhedralComplex"));
-   p_out.take("VERTICES") << V_out;
-   p_out.take("MAXIMAL_POLYTOPES") << IncidenceMatrix<>(vif_vector);
-   return p_out;
+   return BigObject("PolyhedralComplex", mlist<Scalar>(),
+                    "VERTICES", V_out,
+                    "MAXIMAL_POLYTOPES", IncidenceMatrix<>(vif_vector));
 }
 
 template <typename Scalar, typename TVector>
-perl::Object mixed_subdivision(const Array<perl::Object>& p_array,
-                               const Array<Set<int>>& vertices_in_cells,
+BigObject mixed_subdivision(const Array<BigObject>& p_array,
+                               const Array<Set<Int>>& vertices_in_cells,
                                const GenericVector<TVector>& t,
-                               perl::OptionSet options)
+                               OptionSet options)
 {
    return mixed_subdivision<Scalar>(p_array.size(),
                                     polytope::cayley_embedding(p_array, Vector<Scalar>(), options),
@@ -90,12 +88,12 @@ perl::Object mixed_subdivision(const Array<perl::Object>& p_array,
 }
 
 template <typename Scalar>
-perl::Object mixed_subdivision(const perl::Object& p_in1, const perl::Object& p_in2,
-                               const Array<Set<int>>& vertices_in_cells,
+BigObject mixed_subdivision(const BigObject& p_in1, const BigObject& p_in2,
+                               const Array<Set<Int>>& vertices_in_cells,
                                const Scalar& t, const Scalar& t_prime,
-                               perl::OptionSet options)
+                               OptionSet options)
 {
-   const Array<perl::Object> p_array{ p_in1, p_in2 };
+   const Array<BigObject> p_array{ p_in1, p_in2 };
    const Vector<Scalar> t_vec{ t, t_prime };
 
    return mixed_subdivision<Scalar>(p_array, vertices_in_cells, t_vec, options);
@@ -103,7 +101,7 @@ perl::Object mixed_subdivision(const perl::Object& p_in1, const perl::Object& p_
 
 
 UserFunctionTemplate4perl("# @category Producing a polyhedral complex"
-                          "# Create a weighted mixed subdivision of the Minkowski sum of two polytopes, using the Cayley trick."
+                          "# Create a weighted mixed subdivision of the scaled Minkowski sum of two polytopes, using the Cayley trick."
                           "# The polytopes must have the same dimension, at least one of them must be pointed. "
                           "# The vertices of the first polytope //P_0// are weighted with //t_0//,"
                           "# and the vertices of the second polytope //P_1// with //t_1//."
@@ -139,6 +137,7 @@ UserFunctionTemplate4perl("# @category Producing a polyhedral complex"
                           "# Each vertex //v// of the //i//-th polytope is weighted with //t_i//, "
                           "# the //i//-th entry of the optional array //t//. "
                           "# @param Array<Polytope> A the input polytopes"
+			  "# @param Array<Set> VIF the indices of the vertices of the mixed cells"
                           "# @option Vector<Scalar> t scaling for the Cayley embedding; defaults to the all-1 vector"
                           "# @option Bool no_labels Do not copy [[VERTEX_LABELS]] from the original polytopes. default: 0"
                           "# @return PolyhedralComplex",
